import { Uhlive } from "../dist/main.esm.js";
import { identifier, token, url } from "./settings.js";

const logs = document.getElementById("logs");

const uhlive = new Uhlive(identifier, token, {
    logger: (kind, msg) => {
        addLogEntry(kind, msg);
    },
    url,
});
uhlive.onError((msg) => addLogEntry("error", msg));
uhlive.onClose((msg) => addLogEntry("info", msg));

let conversation;

function connect() {
    uhlive.connect();

    document.getElementById("status").textContent = "Connected";

    document.getElementById("connect").classList.add("hidden");
    document.getElementById("disconnect").classList.remove("hidden");
    document.getElementById("join").disabled = false;
    document.getElementById("join").classList.remove("hidden");
}

function join() {
    const conversationId = Math.random().toString(36).substring(7);
    conversation = uhlive
        .join(conversationId)
        .onClose((msg) => {
            addLogEntry("info", msg);
        })
        .onError((msg) => {
            addLogEntry("error", msg);
        })
        .onWordsDecoded((payload) => {
            addSegment(payload);
        })
        .onSegmentDecoded((payload) => {
            addSegment(payload);
        })
        .onSpeakerLeft((speaker) => {
            addLogEntry("info", `User ${speaker} left the conversation.`);
        });

    document.getElementById("status").textContent = "Room joined";

    document.getElementById("join").classList.add("hidden");
    document.getElementById("leave").classList.remove("hidden");
}

function addSegment(payload) {
    let segment = document.getElementById(
        `${payload.speaker}-${payload.start}`,
    );
    if (segment) {
        segment.textContent = `${payload.transcript}`;
    } else {
        segment = document.createElement("div");
        segment.id = `${payload.speaker}-${payload.start}`;
        segment.textContent = `${payload.transcript}`;
        document.getElementById("transcript").appendChild(segment);
    }
    document.getElementById("transcript").scrollTop = document.getElementById(
        "transcript",
    ).scrollHeight;
}

function leave() {
    conversation.leave();

    document.getElementById("status").textContent = "Room left";

    document.getElementById("join").classList.remove("hidden");
    document.getElementById("leave").classList.add("hidden");
}

function disconnect() {
    uhlive.disconnect();

    document.getElementById("status").textContent = "Disconnected";

    document.getElementById("connect").classList.remove("hidden");
    document.getElementById("disconnect").classList.add("hidden");
    document.getElementById("join").classList.remove("hidden");
    document.getElementById("join").disabled = true;
    document.getElementById("leave").classList.add("hidden");
}

function addLogEntry(kind, msg) {
    const entry = document.createElement("div");
    entry.innerHTML = `- ${kind}: ${msg}`;
    entry.style.display = "flex-box";
    logs.appendChild(entry);
    document.getElementById("logs").scrollTop = document.getElementById(
        "logs",
    ).scrollHeight;
}

document.getElementById("connect").onclick = connect;
document.getElementById("join").onclick = join;
document.getElementById("leave").onclick = leave;
document.getElementById("disconnect").onclick = disconnect;
